import {
  csvParse,
  select,
  min,
  max,
  extent,
  group,
  flatGroup,
  rollup,
  flatRollup,
  sum,
  bin,
} from 'd3';

export const viz = (
  container,
  { state, setState }
) => {
  if (state.data && state.data !== 'LOADING') {
    const data = state.data;
   
    const summary = flatRollup(
      data,
      (v) =>
        sum(v, (d) => d.sepal_length) / v.length,
      (d) => d.species
    ).map(([species, avg]) => ({
      species,
      avgSepalLength: avg,
    }));

    select(container)
      .selectAll('pre')
      .data([null])
      .join('pre')
      .text(JSON.stringify(summary, null, 2));
  }

  // state.data could be:
  // * undefined
  // * 'LOADING'
  // * An array of objects
  const { data } = state;

  if (data === undefined) {
    setState((state) => ({
      ...state,
      data: 'LOADING',
    }));
    fetch('data.csv')
      .then((response) => response.text())
      .then((csvString) => {
        const data = csvParse(csvString);

        for (const d of data) {
          d.petal_length = +d.petal_length;
          d.petal_width = +d.petal_width;
          d.sepal_length = +d.sepal_length;
          d.sepal_width = +d.sepal_width;
        }

        setState((state) => ({
          ...state,
          data,
        }));
      });
  }
};